import type { ApiKeyIdentity, ApiKeyIdentityProvider } from "@stedi/sdk-types";
import { FromIniInit } from "./from-ini";
interface FromStaticIdentity {
    readonly apiKey?: ApiKeyIdentity;
}
export type ProviderChainNodeInit = FromStaticIdentity & FromIniInit & {
    /**
     * Provider chain will continue even when no identity is resolved.
     * @default false
     */
    continueOnError?: boolean;
};
/**
 * Creates a credential provider that will attempt to find identity from the
 * following sources (listed in order of precedence):
 *   * Environment variables exposed via `process.env`
 *   * Shared identity and config ini files
 *
 * The default credential provider will invoke one provider at a time and only
 * continue to the next if no identity have been located. For example, if
 * the process finds values defined via the `STEDI_API_KEY` environment
 * variables, the files at `~/.cache/stedi` and `~/.config/stedi`
 * will not be read.
 *
 * @param init                  Configuration that is passed to each individual
 *                              provider
 *
 * @see fromEnv                 The function used to source identity from
 *                              environment variables
 * @see fromIni                 The function used to source identity from INI
 *                              files
 */
export declare const providerChainNode: (init?: ProviderChainNodeInit) => ApiKeyIdentityProvider;
export {};
